@@ -11,12 +11,18 @@ Alien::libswe - Build and install Swiss Ephemeris shared library
 
 =cut
 
-our $VERSION = "0.004";
+our $VERSION = "0.005";
 
 =head1 SYNOPSIS
 
 Build and install Swiss Ephemeris shared library
 
+=head1 DESCRIPTION 
+
+See L<Alien::Build::Manual::AlienUser>
+
+Build and install Swiss Ephemeris shared library
+
 =head1 AUTHOR
 
 Mike Baas <mbaas at cpan.org>
